# Changelog

## [0.6.0] - 2025-01-03

### Features
- Add dunder to easily show doimbu version at the command line  
  (doimbu version, not docker image version).


## [0.5.0] - 2025-01-02

### Features
- Give a proper message when `[ROOT]/variants/` is missing, instead an error.


## [0.4.2] - 2025-01-02

### Fixes
- Fix BUILDER_CONFIG_PATH root dir bug  


## [0.4.1] - 2025-01-02

### Docs
- usage documentation (README)  

### Fixes
- Packages import in `test_builder.py` and `test_file_config-py`.  
  (making them work via command line - previously only in IDE).

### Refactors
- Configuration file renamed from `doimbu-config.ini` to `doimbu.ini`.


## 0.4.0 - 2024-12-31

### Added

- pypi
  - pypi metadata
  - first pypi publish


## [0.3.0] - 2024-12-29

### Added

- LICENSE  
- CHANGELOG  
- CONTRIBUTING  


## [0.2.0] - 2024-12-29

_Initial release_

[0.2.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.2.0
[0.3.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.3.0
[0.4.1]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.4.1
[0.4.2]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.4.2
[0.5.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.5.0
[0.6.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.6.0